@@ -230,9 +230,9 @@ relevant.  DATE has the same format as that returned by `current-time'."
                        (cons "" :skip))
                       ((pred stringp) denote-journal-title-format)
                       ('day "%A")
-                      ('day-date-month-year "%A %e %B %Y")
-                      ('day-date-month-year-24h "%A %e %B %Y %H:%M")
-                      ('day-date-month-year-12h "%A %e %B %Y %I:%M %^p"))))
+                      ('day-date-month-year "%A %-e %B %Y")
+                      ('day-date-month-year-24h "%A %-e %B %Y %H:%M")
+                      ('day-date-month-year-12h "%A %-e %B %Y %I:%M %^p"))))
     (if (consp specifiers)
         (car specifiers)
       (format-time-string specifiers date))))
